yakumo.nova.v2.certificate

Package yakumo :: Package nova :: Package v2 :: Module certificate |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.nova.v2.certificate

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for root certificates in Compute API v2
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23  from yakumo import utils
    24
    25
    26  ATTRIBUTE_MAPPING = [
    27      ('data', 'data', mapper.Noop),
    28      ('private_key', 'private_key', mapper.Noop),
    29  ]
    30
    31
    32 -class Resource(base.Resource):
    33      """Resource class for root certificates in Compute API v2"""
    34
    35
    36 -class Manager(base.Manager):
    37      """Manager class for root certificates in Compute API v2"""
    38
    39      resource_class = Resource
    40      service_type = 'compute'
    41      _attr_mapping = ATTRIBUTE_MAPPING
    42      _hidden_methods = ["update", "list", "find", "find_one"]
    43      _id_attr = 'private_key'
    44      _json_resource_key = 'certificate'
    45      _json_resources_key = 'certificates'
    46      _url_resource_path = '/os-certificates'
    47
    48 -    def create(self, data=UNDEF, private_key=UNDEF):
    49          """
    50          Register a root certificate
    51
    52          @keyword data: Certificate data (str, required)
    53          @type data: Certificate data (str, required)
    54          @keyword private_key: Priate key data (str)
    55          @type private_key: Priate key data (str)
    56          @return: Registered root certificate
    57          @rtype: yakumo.nova.v2.certificate.Resource
    58          """
    59          self._http.post(self._url_resource_path,
    60                          data=utils.get_json_body('certificate',
    61                                                   data=data,
    62                                                   private_key=private_key))
    63
    64 -    def get(self):
    65          ret = self._http.get(self._url_resource_path)
    66          return ret.get('certificate')
    67